<?php
namespace FiloBlu\Countdown\Controller\Adminhtml\Countdown;

use Magento\Backend\App\Action;

class Delete extends \Magento\Backend\App\Action
{
    protected $countdownFactory;
    protected $countdownTranslationsFactory;

    public function __construct(
        Action\Context $context,
        \FiloBlu\Countdown\Model\CountdownFactory $countdownFactory,
        \FiloBlu\Countdown\Model\CountdownTranslationsFactory $countdownTranslationsFactory
    )
    {
        $this->countdownFactory = $countdownFactory;
        $this->countdownTranslationsFactory = $countdownTranslationsFactory;
        parent::__construct($context);
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_Countdown::config');
    }

    /**
     * Delete action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        $storeId = $this->getRequest()->getParam('store',0);

        $isSavingTranslation = false;

        if ($id && $storeId != 0) {
            $isSavingTranslation = true;
        }

        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {

                if ($isSavingTranslation) {
                    $model = $this->countdownTranslationsFactory->create();
                    $model->loadByParentAndStoreId($id,$storeId);
                }
                else {
                    $model = $this->countdownFactory->create();
                    $model->load($id);
                }


                $model->delete();
                $this->messageManager->addSuccess(__('The countdown has been deleted.'));

                if ($isSavingTranslation) {
                    return $resultRedirect->setPath('*/*/edit', ['id' => $id, 'store' => 0]);
                }
                else {
                    return $resultRedirect->setPath('*/*/');
                }

            } catch (\Exception $e) {
                $this->messageManager->addError($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', ['id' => $id, 'store' => $storeId]);
            }
        }
        $this->messageManager->addError(__('We can\'t find a countdown to delete.'));
        return $resultRedirect->setPath('*/*/');
    }
}