<?php

namespace FiloBlu\Countdown\Model;

use Magento\Framework\Model\AbstractModel;

class Countdown extends AbstractModel
{

    const CACHE_TAG = 'fb_countdown';

    protected $_cacheTag = self::CACHE_TAG;

    protected $storeManager;
    protected $countdownCollectionFactory;
    protected $countdownTranslationsFactory;
    private $objectFactory;


    public function __construct(
        \Magento\Store\Model\StoreManagerInterface $storemanager,
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \FiloBlu\Countdown\Model\ResourceModel\Countdown\CollectionFactory $countdownCollectionFactory,
        \FiloBlu\Countdown\Model\CountdownTranslationsFactory $countdownTranslationsFactory,
        \Magento\Framework\DataObjectFactory $objectFactory,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
        array $data = []
    )
    {
        $this->countdownCollectionFactory = $countdownCollectionFactory;
        $this->countdownTranslationsFactory = $countdownTranslationsFactory;
        $this->storeManager = $storemanager;
        $this->objectFactory = $objectFactory;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);

    }

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {

        $this->_init('FiloBlu\Countdown\Model\ResourceModel\Countdown');
    }

    public function getAvailableStatuses()
    {
        return array(
            0 => "Disabled",
            1 => "Enabled"
        );
    }

    public function getCountdownByCode($code)
    {

        $collection = $this->countdownCollectionFactory->create();
        $collection->addFieldToFilter('enabled', ["eq" => 1]);
        $collection->addFieldToFilter('code', ["eq" => $code]);

        $countdown = $collection->getFirstItem();

        $countdownEntity = $this->objectFactory->create();

        if ($countdown) {
            $countdownTranslations = $this->countdownTranslationsFactory->create()->loadByParentAndStoreId($countdown->getId(), $this->storeManager->getStore()->getId());
            if ($countdownTranslations->getId()) {
                $translations = unserialize($countdownTranslations->getSerializedValues());
                $countdownEntity->setData(array_merge($countdown->getData(), $translations));
            } else {
                $countdownEntity->setData($countdown->getData());
            }

            return $countdownEntity;
        } else {
            return null;
        }

    }

    public function save()
    {
        $this->_cacheTag = self::CACHE_TAG . '_' . $this->getId();
        return parent::save();
    }

    public function afterLoad()
    {
        $this->_cacheTag = self::CACHE_TAG . '_' . $this->getId();
        return parent::_afterLoad();
    }

    public function beforeDelete()
    {
        $this->_cacheTag = self::CACHE_TAG . '_' . $this->getId();
        return parent::beforeDelete();
    }


}
